﻿using System.Text;
using System.Web.Mvc;
using FloatingFactory.QuantcastTag.Models;
using Orchard;
using Orchard.ContentManagement;
using Orchard.Environment.Extensions;
using Orchard.Mvc.Filters;
using Orchard.UI.Resources;

namespace FloatingFactory.QuantcastTag.Filters {
	[OrchardFeature("FloatingFactory.QuantcastTag")]
	public class QuantcastTagFilter : FilterProvider, IResultFilter {
		private readonly IResourceManager _resourceManager;
		private readonly IOrchardServices _orchardServices;

		public QuantcastTagFilter(IResourceManager resourceManager, IOrchardServices orchardServices) {
			_resourceManager = resourceManager;
			_orchardServices = orchardServices;
		}

		#region IResultFilter Members

		public void OnResultExecuting(ResultExecutingContext filterContext) {
			var viewResult = filterContext.Result as ViewResult;
			if (viewResult == null)
				return;


			//Get our part data/record if available for rendering scripts
			var part = _orchardServices.WorkContext.CurrentSite.As<QuantcastTagSettingsPart>();
			if (part == null || string.IsNullOrWhiteSpace(part.QuantcastTagKey))
				return; // Not a valid configuration, ignore filter

			//HEADER SCRIPT
			var headerScript = new StringBuilder(800);
			headerScript.AppendLine("<!-- Quantcast Tag, part 1 -->");
			headerScript.AppendLine("<script type=\"text/javascript\">");
			headerScript.AppendLine("var _qevents=_qevents || [];"); 
			headerScript.AppendLine("(function() {");
			headerScript.AppendLine("var elem=document.createElement('script');");
			headerScript.AppendLine("elem.src=(document.location.protocol==\"https:\" ? \"https://secure\":\"http://edge\")+\".quantserve.com/quant.js\";");
			headerScript.AppendLine("elem.async=true;");
			headerScript.AppendLine("elem.type=\"text/javascript\";");
			headerScript.AppendLine("var scpt=document.getElementsByTagName('script')[0];");
			headerScript.AppendLine("scpt.parentNode.insertBefore(elem, scpt);");
			headerScript.AppendLine("})();");
			headerScript.AppendLine("</script>");
			// Register Quantcast Tag's analytics script to the header
			_resourceManager.RegisterHeadScript(headerScript.ToString());

			//FOOTER SCRIPT
			var footerScript = new StringBuilder(700);
			footerScript.AppendLine("<!-- Quantcast Tag, part 2 -->");
			footerScript.AppendLine("<script type=\"text/javascript\">");
			footerScript.AppendLine("_qevents.push({");
			footerScript.AppendLine("qacct:\"" + part.QuantcastTagKey + "\"");
			footerScript.AppendLine("});");
			footerScript.AppendLine("</script>");
			footerScript.AppendLine("<noscript>");
			footerScript.AppendLine("<div style=\"display:none;\">");
			footerScript.AppendLine("<img src=\"//pixel.quantserve.com/pixel/"  + part.QuantcastTagKey + ".gif\" border=\"0\" height=\"1\" width=\"1\" alt=\"Quantcast\"/>");
			footerScript.AppendLine("</div>");
			footerScript.AppendLine("</noscript>");
			footerScript.AppendLine("<!-- End Quantcast tag -->");
			// Register Quantcast Tag's analytics analytics script to the footer
			_resourceManager.RegisterFootScript(footerScript.ToString());

		}

		public void OnResultExecuted(ResultExecutedContext filterContext) {
		}

		#endregion
	}
}